Index: chrome/common/render_messages_params.h |
diff --git a/chrome/common/render_messages_params.h b/chrome/common/render_messages_params.h |
index 2eeff7075862e0aab4c24df2351b736ca06d5dea..211de1aee0d9c6ebf7872e4054df6e43198e8137 100644 |
--- a/chrome/common/render_messages_params.h |
+++ b/chrome/common/render_messages_params.h |
@@ -321,9 +321,12 @@ struct ViewHostMsg_UpdateRect_Params { |
ViewHostMsg_UpdateRect_Params(); |
~ViewHostMsg_UpdateRect_Params(); |
- // The bitmap to be painted into the view at the locations specified by |
- // update_rects. |
- TransportDIB::Id bitmap; |
+ // The ID of the bitmap to be painted into the view at the locations specified |
+ // by update_rects. |
+ TransportDIB::Id dib_id; |
+ |
+ // The handle to the bitmap, in case it needs to be mapped on the browser. |
+ TransportDIB::Handle dib_handle; |
// The position and size of the bitmap. |
gfx::Rect bitmap_rect; |